@@ -3,6 +3,7 @@ from typing import TYPE_CHECKING, Any
 
 from github.CheckRun import CheckRun
 from github.PullRequest import PullRequest
+from github.Repository import Repository
 
 from webhook_server.libs.labels_handler import LabelsHandler
 from webhook_server.libs.owners_files_handler import OwnersFileHandler
@@ -32,8 +33,8 @@ class CheckRunHandler:
         self.owners_file_handler = owners_file_handler
         self.hook_data = self.github_webhook.hook_data
         self.logger = self.github_webhook.logger
-        self.log_prefix = self.github_webhook.log_prefix
-        self.repository = self.github_webhook.repository
+        self.log_prefix: str = self.github_webhook.log_prefix
+        self.repository: Repository = self.github_webhook.repository
         if isinstance(self.owners_file_handler, OwnersFileHandler):
             self.labels_handler = LabelsHandler(
                 github_webhook=self.github_webhook, owners_file_handler=self.owners_file_handler
@@ -45,6 +46,8 @@ class CheckRunHandler:
         _check_run: dict[str, Any] = self.hook_data["check_run"]
         check_run_name: str = _check_run["name"]
 
+        self.logger.step(f"{self.log_prefix} Processing check run: {check_run_name}")  # type: ignore
+
         if self.hook_data.get("action", "") != "completed":
             self.logger.debug(
                 f"{self.log_prefix} check run {check_run_name} action is {self.hook_data.get('action', 'N/A')} and not completed, skipping"
@@ -63,7 +66,9 @@ class CheckRunHandler:
                     label=AUTOMERGE_LABEL_STR, pull_request=pull_request
                 ):
                     try:
+                        self.logger.step(f"{self.log_prefix} Executing auto-merge for PR #{pull_request.number}")  # type: ignore
                         await asyncio.to_thread(pull_request.merge, merge_method="SQUASH")
+                        self.logger.step(f"{self.log_prefix} Auto-merge completed successfully")  # type: ignore
                         self.logger.info(
                             f"{self.log_prefix} Successfully auto-merged pull request #{pull_request.number}"
                         )
@@ -212,6 +217,16 @@ class CheckRunHandler:
 
         msg: str = f"{self.log_prefix} check run {check_run} status: {status or conclusion}"
 
+        # Log workflow steps for check run status changes
+        if status == QUEUED_STR:
+            self.logger.step(f"{self.log_prefix} Setting {check_run} check to queued")  # type: ignore
+        elif status == IN_PROGRESS_STR:
+            self.logger.step(f"{self.log_prefix} Setting {check_run} check to in-progress")  # type: ignore
+        elif conclusion == SUCCESS_STR:
+            self.logger.step(f"{self.log_prefix} Setting {check_run} check to success")  # type: ignore
+        elif conclusion == FAILURE_STR:
+            self.logger.step(f"{self.log_prefix} Setting {check_run} check to failure")  # type: ignore
+
         try:
             self.logger.debug(f"{self.log_prefix} Set check run status with {kwargs}")
             await asyncio.to_thread(self.github_webhook.repository_by_github_app.create_check_run, **kwargs)
