@@ -1,17 +1,22 @@
 import hashlib
 import hmac
+import ipaddress
 import json
 import os
 from typing import Any
-from unittest.mock import Mock, patch, AsyncMock
+from unittest.mock import AsyncMock, Mock, patch
 
 import httpx
 import pytest
 from fastapi.testclient import TestClient
-import ipaddress
 
-from webhook_server.app import FASTAPI_APP, gate_by_allowlist_ips
-from webhook_server.libs.exceptions import RepositoryNotFoundError
+from webhook_server.app import FASTAPI_APP
+from webhook_server.libs.exceptions import RepositoryNotFoundInConfigError
+from webhook_server.utils.app_utils import (
+    gate_by_allowlist_ips,
+    get_cloudflare_allowlist,
+    get_github_allowlist,
+)
 
 
 class TestWebhookApp:
@@ -124,7 +129,7 @@ class TestWebhookApp:
     ) -> None:
         """Test webhook processing when repository is not found in config."""
         # Mock GithubWebhook to raise RepositoryNotFoundError
-        mock_github_webhook.side_effect = RepositoryNotFoundError("Repository not found in configuration")
+        mock_github_webhook.side_effect = RepositoryNotFoundInConfigError("Repository not found in configuration")
 
         payload_json = json.dumps(valid_webhook_payload)
         signature = self.create_github_signature(payload_json, webhook_secret)
@@ -236,12 +241,9 @@ class TestWebhookApp:
         async_client = AsyncMock()
         async_client.get.return_value = mock_response
 
-        from webhook_server import app as app_module
-
-        with patch.object(app_module, "_lifespan_http_client", async_client):
-            result = await app_module.get_github_allowlist()
-            assert result == ["192.30.252.0/22", "185.199.108.0/22"]
-            async_client.get.assert_called_once()
+        result = await get_github_allowlist(async_client)
+        assert result == ["192.30.252.0/22", "185.199.108.0/22"]
+        async_client.get.assert_called_once()
 
     @patch("httpx.AsyncClient.get")
     async def test_get_github_allowlist_error(self, mock_get: Mock) -> None:
@@ -251,11 +253,8 @@ class TestWebhookApp:
         async_client = AsyncMock()
         async_client.get.side_effect = httpx.RequestError("Network error")
 
-        from webhook_server import app as app_module
-
-        with patch.object(app_module, "_lifespan_http_client", async_client):
-            with pytest.raises(httpx.RequestError):
-                await app_module.get_github_allowlist()
+        with pytest.raises(httpx.RequestError):
+            await get_github_allowlist(async_client)
 
     @patch("httpx.AsyncClient.get")
     async def test_get_cloudflare_allowlist_success(self, mock_get: Mock) -> None:
@@ -270,77 +269,67 @@ class TestWebhookApp:
         async_client = AsyncMock()
         async_client.get.return_value = mock_response
 
-        from webhook_server import app as app_module
-
-        with patch.object(app_module, "_lifespan_http_client", async_client):
-            result = await app_module.get_cloudflare_allowlist()
-            assert result == ["103.21.244.0/22", "2400:cb00::/32"]
-            async_client.get.assert_called_once()
+        result = await get_cloudflare_allowlist(async_client)
+        assert result == ["103.21.244.0/22", "2400:cb00::/32"]
+        async_client.get.assert_called_once()
 
     @pytest.mark.asyncio
-    async def test_gate_by_allowlist_ips_allowed(self, monkeypatch: Any) -> None:
+    async def test_gate_by_allowlist_ips_allowed(self) -> None:
         """Test gate_by_allowlist_ips with allowed IP."""
-        # Patch ALLOWED_IPS to allow 127.0.0.1
-        monkeypatch.setattr("webhook_server.app.ALLOWED_IPS", (ipaddress.ip_network("127.0.0.1/32"),))
+        allowed_ips = (ipaddress.ip_network("127.0.0.1/32"),)
 
         class DummyRequest:
             client = type("client", (), {"host": "127.0.0.1"})()
 
-        await gate_by_allowlist_ips(DummyRequest())  # type: ignore
+        await gate_by_allowlist_ips(DummyRequest(), allowed_ips)  # type: ignore
 
     @pytest.mark.asyncio
-    async def test_gate_by_allowlist_ips_forbidden(self, monkeypatch: Any) -> None:
+    async def test_gate_by_allowlist_ips_forbidden(self) -> None:
         """Test gate_by_allowlist_ips with forbidden IP."""
-        monkeypatch.setattr("webhook_server.app.ALLOWED_IPS", (ipaddress.ip_network("10.0.0.0/8"),))
+        allowed_ips = (ipaddress.ip_network("10.0.0.0/8"),)
 
         class DummyRequest:
             client = type("client", (), {"host": "127.0.0.1"})()
 
         with pytest.raises(Exception) as exc:
-            await gate_by_allowlist_ips(DummyRequest())  # type: ignore
+            await gate_by_allowlist_ips(DummyRequest(), allowed_ips)  # type: ignore
         assert "not a valid ip in allowlist" in str(exc.value)
 
     @pytest.mark.asyncio
     async def test_gate_by_allowlist_ips_no_client(self) -> None:
         """Test gate_by_allowlist_ips with no client."""
-        from webhook_server import app as app_module
-
-        app_module.ALLOWED_IPS = (ipaddress.ip_network("127.0.0.1/32"),)
+        allowed_ips = (ipaddress.ip_network("127.0.0.1/32"),)
 
         class DummyRequest:
             client = None
 
         with pytest.raises(Exception) as exc:
-            await gate_by_allowlist_ips(DummyRequest())  # type: ignore
+            await gate_by_allowlist_ips(DummyRequest(), allowed_ips)  # type: ignore
         assert "Could not determine client IP address" in str(exc.value)
 
     @pytest.mark.asyncio
     async def test_gate_by_allowlist_ips_bad_ip(self) -> None:
         """Test gate_by_allowlist_ips with bad IP."""
-        from webhook_server import app as app_module
-
-        app_module.ALLOWED_IPS = (ipaddress.ip_network("127.0.0.1/32"),)
+        allowed_ips = (ipaddress.ip_network("127.0.0.1/32"),)
 
         class DummyRequest:
             class client:
                 host = "not-an-ip"
 
         with pytest.raises(Exception) as exc:
-            await gate_by_allowlist_ips(DummyRequest())  # type: ignore
+            await gate_by_allowlist_ips(DummyRequest(), allowed_ips)  # type: ignore
         assert "Could not parse client IP address" in str(exc.value)
 
     @pytest.mark.asyncio
     async def test_gate_by_allowlist_ips_empty_allowlist(self) -> None:
         """Test gate_by_allowlist_ips with empty allowlist."""
-        from webhook_server import app as app_module
-
-        app_module.ALLOWED_IPS = ()
+        allowed_ips = ()
 
         class DummyRequest:
             client = type("client", (), {"host": "127.0.0.1"})()
 
-        # Should not raise when ALLOWED_IPS is empty
-        await gate_by_allowlist_ips(DummyRequest())  # type: ignore
+        # Should not raise when allowed_ips is empty
+        await gate_by_allowlist_ips(DummyRequest(), allowed_ips)  # type: ignore
 
     @patch.dict(os.environ, {"WEBHOOK_SERVER_DATA_DIR": "webhook_server/tests/manifests"})
     def test_process_webhook_request_body_error(self, client: TestClient) -> None:
@@ -400,25 +389,18 @@ class TestWebhookApp:
         async_client = AsyncMock()
         async_client.get.side_effect = Exception("Unexpected error")
 
-        from webhook_server import app as app_module
+        with pytest.raises(Exception):
+            await get_github_allowlist(async_client)
 
-        with patch.object(app_module, "_lifespan_http_client", async_client):
-            with pytest.raises(Exception):
-                await app_module.get_github_allowlist()
-
-    @patch("httpx.AsyncClient.get")
-    async def test_get_cloudflare_allowlist_request_error(self, mock_get: Mock) -> None:
+    async def test_get_cloudflare_allowlist_request_error(self) -> None:
         """Test Cloudflare allowlist fetching with request error."""
         from unittest.mock import AsyncMock
 
         async_client = AsyncMock()
         async_client.get.side_effect = httpx.RequestError("Network error")
 
-        from webhook_server import app as app_module
-
-        with patch.object(app_module, "_lifespan_http_client", async_client):
-            with pytest.raises(httpx.RequestError):
-                await app_module.get_cloudflare_allowlist()
+        with pytest.raises(httpx.RequestError):
+            await get_cloudflare_allowlist(async_client)
 
     @patch("httpx.AsyncClient.get")
     async def test_get_cloudflare_allowlist_unexpected_error(self, mock_get: Mock) -> None:
@@ -428,16 +410,14 @@ class TestWebhookApp:
         async_client = AsyncMock()
         async_client.get.side_effect = Exception("Unexpected error")
 
-        from webhook_server import app as app_module
-
-        with patch.object(app_module, "_lifespan_http_client", async_client):
-            with pytest.raises(Exception):
-                await app_module.get_cloudflare_allowlist()
+        with pytest.raises(Exception):
+            await get_cloudflare_allowlist(async_client)
 
     @patch("httpx.AsyncClient.get")
     async def test_get_cloudflare_allowlist_http_error(self, mock_get: Mock) -> None:
         """Test Cloudflare allowlist fetching with HTTP error."""
         from unittest.mock import AsyncMock
+
         import httpx
 
         async_client = AsyncMock()
@@ -448,16 +428,14 @@ class TestWebhookApp:
         mock_response.json = lambda: {"result": {}}
         async_client.get.return_value = mock_response
 
-        from webhook_server import app as app_module
-
-        with patch.object(app_module, "_lifespan_http_client", async_client):
-            with pytest.raises(httpx.HTTPStatusError):
-                await app_module.get_cloudflare_allowlist()
+        with pytest.raises(httpx.HTTPStatusError):
+            await get_cloudflare_allowlist(async_client)
 
     @patch("httpx.AsyncClient.get")
     async def test_get_github_allowlist_http_error(self, mock_get: Mock) -> None:
         """Test GitHub allowlist fetching with HTTP error."""
         from unittest.mock import AsyncMock
+
         import httpx
 
         async_client = AsyncMock()
@@ -468,11 +446,8 @@ class TestWebhookApp:
         mock_response.json = lambda: {"hooks": []}
         async_client.get.return_value = mock_response
 
-        from webhook_server import app as app_module
-
-        with patch.object(app_module, "_lifespan_http_client", async_client):
-            with pytest.raises(httpx.HTTPStatusError):
-                await app_module.get_github_allowlist()
+        with pytest.raises(httpx.HTTPStatusError):
+            await get_github_allowlist(async_client)
 
     @patch("webhook_server.app.get_github_allowlist")
     @patch("webhook_server.app.get_cloudflare_allowlist")
@@ -482,8 +457,10 @@ class TestWebhookApp:
         self, mock_urllib3: Mock, mock_config: Mock, mock_cf_allowlist: Mock, mock_gh_allowlist: Mock
     ) -> None:
         """Test successful lifespan function execution."""
+        from unittest.mock import AsyncMock
+        from unittest.mock import patch as patcher
+
         from webhook_server import app as app_module
-        from unittest.mock import AsyncMock, patch as patcher
 
         # Mock config
         mock_config_instance = Mock()
@@ -591,3 +568,73 @@ class TestWebhookApp:
                 pass
             # Should handle both allowlist failures gracefully
             # (You could add log assertion here if desired)
+
+    def test_static_files_path_construction(self) -> None:
+        """Test that the static files path is constructed correctly."""
+        from webhook_server import app as app_module
+
+        # The static_files_path should point to webhook_server/web/static
+        expected_suffix = os.path.join("webhook_server", "web", "static")
+        actual_path = app_module.static_files_path
+
+        # Check that the path contains the expected directory structure
+        # Convert to string and normalize path separators for comparison
+        actual_path_str = str(actual_path)
+        assert actual_path_str.endswith(expected_suffix) or expected_suffix.replace(
+            os.sep, "/"
+        ) in actual_path_str.replace(os.sep, "/")
+
+        # Verify path structure makes sense
+        assert "webhook_server" in actual_path_str
+        assert "web" in actual_path_str
+        assert "static" in actual_path_str
+
+    @patch("webhook_server.app.os.path.exists")
+    @patch("webhook_server.app.os.path.isdir")
+    def test_static_files_validation_logic(self, mock_isdir: Mock, mock_exists: Mock) -> None:
+        """Test static files validation logic without lifespan."""
+        from webhook_server import app as app_module
+
+        # Test case 1: Directory exists and is valid
+        mock_exists.return_value = True
+        mock_isdir.return_value = True
+
+        # This should not raise an exception
+        static_path = app_module.static_files_path
+        if not os.path.exists(static_path):
+            raise FileNotFoundError(f"Static files directory not found: {static_path}")
+        if not os.path.isdir(static_path):
+            raise NotADirectoryError(f"Static files path is not a directory: {static_path}")
+
+        # Test case 2: Directory doesn't exist
+        mock_exists.return_value = False
+        mock_isdir.return_value = False
+
+        with pytest.raises(FileNotFoundError) as exc_info:
+            if not os.path.exists(static_path):
+                raise FileNotFoundError(
+                    f"Static files directory not found: {static_path}. "
+                    f"This directory is required for serving web assets (CSS/JS). "
+                    f"Expected structure: webhook_server/web/static/ with css/ and js/ subdirectories."
+                )
+
+        error_msg = str(exc_info.value)
+        assert "Static files directory not found" in error_msg
+        assert "webhook_server/web/static" in error_msg
+
+        # Test case 3: Path exists but is not a directory
+        mock_exists.return_value = True
+        mock_isdir.return_value = False
+
+        with pytest.raises(NotADirectoryError) as exc_info:
+            if not os.path.exists(static_path):
+                raise FileNotFoundError(f"Path not found: {static_path}")
+            if not os.path.isdir(static_path):
+                raise NotADirectoryError(
+                    f"Static files path exists but is not a directory: {static_path}. "
+                    f"Expected a directory containing css/ and js/ subdirectories."
+                )
+
+        error_msg = str(exc_info.value)
+        assert "exists but is not a directory" in error_msg
+        assert "css/ and js/ subdirectories" in error_msg
